==> elisa-25.07.90.tar.xz: elisa-25.07.90/org.kde.elisa.desktop.cmake <==
[Desktop Entry]
Categories=Qt;KDE;Audio;AudioVideo
Comment=Play local music and listen to online radio
Comment[ar]=شغل الصوتيات المحلية واستمع لمحطات الإذاعة على الإنترنت
Comment[bg]=Възпроизвеждане на локални музикални файлове и слушане на онлайн радиостанции
Comment[ca]=Reproduïu música local i escolteu ràdio en línia
Comment[ca@valencia]=Reproduïu música local i escolteu ràdio en línia
Comment[de]=Lokal gespeicherte Musik abspielen und Online-Radio hören
Comment[eo]=Ludu lokan muzikon kaj aŭskultu al retradio
Comment[es]=Reproduzca música local y escuche radios en línea
Comment[eu]=Musika lokala jotzea eta irratiari lerroan entzutea
Comment[fi]=Soita paikallista musiikkia ja kuuntele verkkoradioasemia
Comment[fr]=Jouer de la musique locale et écouter la radio en ligne
Comment[gl]=Reproduza música local e escoite a radio por Internet.
Comment[he]=השמעת מוזיקה מקומית ולהאזין לרדיו מקוון
Comment[hu]=Helyi zene lejátszása és online rádiók hallgatása
Comment[ia]=Reproduce musica local e ascolta stationes radio in linea
Comment[is]=Spilaðu tónlist af tölvunni og hlustaðu á útvarpsstreymi af netinu
Comment[it]=Riproduci musica locale e ascolta stazioni radio online
Comment[ka]=დაუკარით ადგილობრივი მუსიკა და მოუსმინეთ ონლაინრადიოს
Comment[ko]=로컬 음악 재생 및 온라인 라디오 듣기
Comment[lt]=Atkurti vietinę muziką ir klausytis internetinio radijo
Comment[lv]=Atskaņojiet ierīcē esošo mūziku un klausieties tiešsaistes radiostacijas
Comment[nl]=Speel lokaal muziek en luister naar online radio
Comment[nn]=Spel av lokal musikk og lytt på nettradio
Comment[pl]=Odtwarzaj muzykę lokalnie i słucha radia z sieci
Comment[pt_BR]=Reproduza músicas locais e ouça rádios online
Comment[ru]=Воспроизведение хранящейся локально музыки и прослушивание интернет-радиостанций
Comment[sa]=स्थानीयसङ्गीतं वादयन्तु, ऑनलाइन रेडियो शृणुत च
Comment[sl]=Predvaja lokalno glasbo in posluša spletni radio
Comment[sv]=Spela lokal musik och lyssna på nätradiostationer
Comment[ta]=கணினியிலுள்ள பாடல்கள் மட்டுமின்றி இணைய வானொலி நிலையங்களையும் கேட்கலாம்.
Comment[th]=เล่นเพลงบนเครื่องและฟังวิทยุออนไลน์
Comment[tr]=Yerel müziğinizi çalın ve çevrimiçi radyo dinleyin
Comment[uk]=Відтворення музики з диска і прослуховування інтернет-радіо
Comment[x-test]=xxPlay local music and listen to online radioxx
Comment[zh_CN]=播放本地音乐并收听在线广播
Comment[zh_TW]=播放本機音樂或聆聽線上廣播
Exec=elisa %U
GenericName=Music Player
GenericName[ar]=مشغّل صوتي إليسّا
GenericName[az]=Musiqi Pleyeri
GenericName[be]=Музычны прайгравальнік
GenericName[bg]=Слушане на музика
GenericName[ca]=Reproductor musical
GenericName[ca@valencia]=Reproductor musical
GenericName[cs]=Přehrávač hudby
GenericName[da]=Musikafspiller
GenericName[de]=Musik-Wiedergabe
GenericName[el]=Music Player
GenericName[en_GB]=Music Player
GenericName[eo]=Muzikludilo
GenericName[es]=Reproductor de música
GenericName[et]=Muusikamängija
GenericName[eu]=Musika jotzailea
GenericName[fi]=Musiikkisoitin
GenericName[fr]=Lecteur multimédia
GenericName[gl]=Reprodutor de música
GenericName[he]=נגן מוזיקה
GenericName[hi]=संगीत चालक
GenericName[hu]=Zenelejátszó
GenericName[ia]=Reproductor musical
GenericName[id]=Pemutar Musik
GenericName[is]=Tónlistarspilari
GenericName[it]=Lettore musicale
GenericName[ja]=音楽プレーヤー
GenericName[ka]=მედია დამკვრელი
GenericName[ko]=음악 재생기
GenericName[lt]=Muzikos grotuvas
GenericName[lv]=Mūzikas atskaņotājs
GenericName[nl]=Muziekspeler
GenericName[nn]=Musikkspelar
GenericName[pa]=ਸੰਗੀਤ ਪਲੇਅਰ
GenericName[pl]=Odtwarzacz muzyki
GenericName[pt]=Leitor de Música
GenericName[pt_BR]=Reprodutor de músicas
GenericName[ro]=Lector audio
GenericName[ru]=Музыкальный проигрыватель
GenericName[sa]=संगीतवादकः
GenericName[sk]=Hudobný prehrávač
GenericName[sl]=Predvajalnik glasbe
GenericName[sv]=Musikspelare
GenericName[ta]=பாடல் இசைப்பி
GenericName[th]=เครื่องเล่นเพลง
GenericName[tr]=Müzik Çalar
GenericName[uk]=Музичний програвач
GenericName[x-test]=xxMusic Playerxx
GenericName[zh_CN]=音乐播放器
GenericName[zh_TW]=音樂播放器
Icon=elisa
Name=Elisa
Name[ar]=إليسّا
Name[ast]=Elisa
Name[az]=Elisa
Name[be]=Elisa
Name[bg]=Elisa
Name[ca]=Elisa
Name[ca@valencia]=Elisa
Name[cs]=Elisa
Name[da]=Elisa
Name[de]=Elisa
Name[el]=Elisa
Name[en_GB]=Elisa
Name[eo]=Elisa
Name[es]=Elisa
Name[et]=Elisa
Name[eu]=Elisa
Name[fi]=Elisa
Name[fr]=Elisa
Name[gl]=Elisa
Name[he]=אליסה
Name[hi]=एलिसा
Name[hu]=Elisa
Name[ia]=Elisa
Name[id]=Elisa
Name[is]=Elisa
Name[it]=Elisa
Name[ja]=Elisa
Name[ka]=Elisa
Name[ko]=Elisa
Name[lt]=Elisa
Name[lv]=Elisa
Name[nl]=Elisa
Name[nn]=Elisa
Name[pa]=ਇਲੀਸਾ
Name[pl]=Elisa
Name[pt]=Elisa
Name[pt_BR]=Elisa
Name[ro]=Elisa
Name[ru]=Elisa
Name[sa]=एलिसा
Name[sk]=Elisa
Name[sl]=Elisa
Name[sv]=Elisa
Name[ta]=எலைசா
Name[th]=Elisa
Name[tr]=Elisa
Name[uk]=Elisa
Name[x-test]=xxElisaxx
Name[zh_CN]=Elisa 音乐播放器
Name[zh_TW]=Elisa
StartupWMClass=elisa
Type=Application
MimeType=audio/aac;audio/mp4;audio/mpeg;audio/mpegurl;audio/vnd.rn-realaudio;audio/vorbis;audio/x-flac;audio/x-mp3;audio/x-mpegurl;audio/x-ms-wma;audio/x-musepack;audio/x-oggflac;audio/x-pn-realaudio;audio/x-scpls;audio/x-speex;audio/x-vorbis;audio/x-wav;application/x-ogm-audio;audio/x-vorbis+ogg;audio/ogg;
SingleMainWindow=true
@ELISA_DBUSACTIVATABLE@

==> elisa-25.08.3.tar.xz: elisa-25.08.3/org.kde.elisa.desktop.cmake <==
[Desktop Entry]
Categories=Qt;KDE;Audio;AudioVideo
Comment=Play local music and listen to online radio
Comment[ar]=شغل الصوتيات المحلية واستمع لمحطات الإذاعة على الإنترنت
Comment[bg]=Възпроизвеждане на локални музикални файлове и слушане на онлайн радиостанции
Comment[ca]=Reproduïu música local i escolteu ràdio en línia
Comment[ca@valencia]=Reproduïu música local i escolteu ràdio en línia
Comment[cs]=Přehrávejte si místní hudbu a poslouchejte online rádia
Comment[de]=Lokal gespeicherte Musik abspielen und Online-Radio hören
Comment[eo]=Ludu lokan muzikon kaj aŭskultu al retradio
Comment[es]=Reproduzca música local y escuche radios en línea
Comment[eu]=Musika lokala jotzea eta irratiari lerroan entzutea
Comment[fi]=Soita paikallista musiikkia ja kuuntele verkkoradioasemia
Comment[fr]=Jouer de la musique locale et écouter la radio en ligne
Comment[gl]=Reproduza música local e escoite a radio por Internet.
Comment[he]=השמעת מוזיקה מקומית ולהאזין לרדיו מקוון
Comment[hu]=Helyi zene lejátszása és online rádiók hallgatása
Comment[ia]=Reproduce musica local e ascolta stationes radio in linea
Comment[is]=Spilaðu tónlist af tölvunni og hlustaðu á útvarpsstreymi af netinu
Comment[it]=Riproduci musica locale e ascolta stazioni radio online
Comment[ka]=დაუკარით ადგილობრივი მუსიკა და მოუსმინეთ ონლაინრადიოს
Comment[ko]=로컬 음악 재생 및 온라인 라디오 듣기
Comment[lt]=Atkurti vietinę muziką ir klausytis internetinio radijo
Comment[lv]=Atskaņojiet ierīcē esošo mūziku un klausieties tiešsaistes radiostacijas
Comment[nl]=Speel lokaal muziek en luister naar online radio
Comment[nn]=Spel av lokal musikk og lytt på nettradio
Comment[pl]=Odtwarzaj muzykę lokalnie i słucha radia z sieci
Comment[pt_BR]=Reproduza músicas locais e ouça rádios online
Comment[ro]=Redă muzică locală și ascultă stații radio prin Internet
Comment[ru]=Воспроизведение хранящейся локально музыки и прослушивание интернет-радиостанций
Comment[sa]=स्थानीयसङ्गीतं वादयन्तु, ऑनलाइन रेडियो शृणुत च
Comment[sl]=Predvaja lokalno glasbo in posluša spletni radio
Comment[sv]=Spela lokal musik och lyssna på nätradiostationer
Comment[ta]=கணினியிலுள்ள பாடல்கள் மட்டுமின்றி இணைய வானொலி நிலையங்களையும் கேட்கலாம்.
Comment[th]=เล่นเพลงบนเครื่องและฟังวิทยุออนไลน์
Comment[tr]=Yerel müziğinizi çalın ve çevrimiçi radyo dinleyin
Comment[uk]=Відтворення музики з диска і прослуховування інтернет-радіо
Comment[zh_CN]=播放本地音乐并收听在线广播
Comment[zh_TW]=播放本機音樂或聆聽線上廣播
Exec=elisa %U
GenericName=Music Player
GenericName[ar]=مشغّل صوتي إليسّا
GenericName[az]=Musiqi Pleyeri
GenericName[be]=Музычны прайгравальнік
GenericName[bg]=Слушане на музика
GenericName[ca]=Reproductor musical
GenericName[ca@valencia]=Reproductor musical
GenericName[cs]=Přehrávač hudby
GenericName[da]=Musikafspiller
GenericName[de]=Musik-Wiedergabe
GenericName[el]=Music Player
GenericName[en_GB]=Music Player
GenericName[eo]=Muzikludilo
GenericName[es]=Reproductor de música
GenericName[et]=Muusikamängija
GenericName[eu]=Musika jotzailea
GenericName[fi]=Musiikkisoitin
GenericName[fr]=Lecteur multimédia
GenericName[gl]=Reprodutor de música
GenericName[he]=נגן מוזיקה
GenericName[hi]=संगीत चालक
GenericName[hu]=Zenelejátszó
GenericName[ia]=Reproductor musical
GenericName[id]=Pemutar Musik
GenericName[is]=Tónlistarspilari
GenericName[it]=Lettore musicale
GenericName[ja]=音楽プレーヤー
GenericName[ka]=მედია დამკვრელი
GenericName[ko]=음악 재생기
GenericName[lt]=Muzikos grotuvas
GenericName[lv]=Mūzikas atskaņotājs
GenericName[nl]=Muziekspeler
GenericName[nn]=Musikkspelar
GenericName[pa]=ਸੰਗੀਤ ਪਲੇਅਰ
GenericName[pl]=Odtwarzacz muzyki
GenericName[pt]=Leitor de Música
GenericName[pt_BR]=Reprodutor de músicas
GenericName[ro]=Lector audio
GenericName[ru]=Музыкальный проигрыватель
GenericName[sa]=संगीतवादकः
GenericName[sk]=Hudobný prehrávač
GenericName[sl]=Predvajalnik glasbe
GenericName[sv]=Musikspelare
GenericName[ta]=பாடல் இசைப்பி
GenericName[th]=เครื่องเล่นเพลง
GenericName[tr]=Müzik Çalar
GenericName[uk]=Музичний програвач
GenericName[zh_CN]=音乐播放器
GenericName[zh_TW]=音樂播放器
Icon=elisa
Name=Elisa
Name[ar]=إليسّا
Name[ast]=Elisa
Name[az]=Elisa
Name[be]=Elisa
Name[bg]=Elisa
Name[ca]=Elisa
Name[ca@valencia]=Elisa
Name[cs]=Elisa
Name[da]=Elisa
Name[de]=Elisa
Name[el]=Elisa
Name[en_GB]=Elisa
Name[eo]=Elisa
Name[es]=Elisa
Name[et]=Elisa
Name[eu]=Elisa
Name[fi]=Elisa
Name[fr]=Elisa
Name[gl]=Elisa
Name[he]=אליסה
Name[hi]=एलिसा
Name[hu]=Elisa
Name[ia]=Elisa
Name[id]=Elisa
Name[is]=Elisa
Name[it]=Elisa
Name[ja]=Elisa
Name[ka]=Elisa
Name[ko]=Elisa
Name[lt]=Elisa
Name[lv]=Elisa
Name[nl]=Elisa
Name[nn]=Elisa
Name[pa]=ਇਲੀਸਾ
Name[pl]=Elisa
Name[pt]=Elisa
Name[pt_BR]=Elisa
Name[ro]=Elisa
Name[ru]=Elisa
Name[sa]=एलिसा
Name[sk]=Elisa
Name[sl]=Elisa
Name[sv]=Elisa
Name[ta]=எலைசா
Name[th]=Elisa
Name[tr]=Elisa
Name[uk]=Elisa
Name[zh_CN]=Elisa 音乐播放器
Name[zh_TW]=Elisa
StartupWMClass=elisa
Type=Application
MimeType=audio/aac;audio/mp4;audio/mpeg;audio/mpegurl;audio/vnd.rn-realaudio;audio/vorbis;audio/x-flac;audio/x-mp3;audio/x-mpegurl;audio/x-ms-wma;audio/x-musepack;audio/x-oggflac;audio/x-pn-realaudio;audio/x-scpls;audio/x-speex;audio/x-vorbis;audio/x-wav;application/x-ogm-audio;audio/x-vorbis+ogg;audio/ogg;
SingleMainWindow=true
@ELISA_DBUSACTIVATABLE@
